@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 #-------------------------------------------------------------------------------
 
@@ -21,18 +21,19 @@ sub new {
 sub get_info {
     my $self = shift;
     $self->{info}{osname} = 'Mac';
+    $self->{info}{osflag}       = $^O;
     
     my $uname_s = $self->_command('uname -s');
     if ($uname_s =~ /Darwin/i) {
         $self->{info}{oslabel} = 'OS X';
         
         my $productversion = $self->_command('sw_vers -productVersion');
-        if ($productversion =~ /(\d+)\.(\d+)\.(\d+)/) {
-            my ($major, $minor, $release) = ($1, $2, $3);
+        if ($productversion =~ /((\d+)\.(\d+)(\.(\d+))?)/) {
+            my ($version, $major, $minor) = ($1, $2, $3);
             my $versions = _macos_versions();
             if (my $codename = $versions->{"$major.$minor"}) {
                 $self->{info}{codename} = $codename;
-                $self->{info}{osvers}  = "$major.$minor.$release";
+                $self->{info}{osvers}  = $version;
             }
         }
     }
@@ -160,4 +161,4 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
 
-=cut
\ No newline at end of file
+=cut
